@@ -11,15 +11,15 @@ CrossEntropyClustering=function(Data,ClusterNo,PlotIt=FALSE,...){
   # Object            Object of CEC::cec algorithm
   #
   # Author: MT
-  if (!requireNamespace('CEC')) {
+  if (!requireNamespace('CEC',quietly = TRUE)) {
     message(
-      'Subordinate clustering package is missing. No computations are performed.
+      'Subordinate clustering package (CEC) is missing. No computations are performed.
             Please install the package which is defined in "Suggests".'
     )
     return(
       list(
         Cls = rep(1, nrow(Data)),
-        Object = "Subordinate clustering package is missing.
+        Object = "Subordinate clustering package (CEC) is missing.
                 Please install the package which is defined in 'Suggests'."
       )
     )
