@@ -7,15 +7,15 @@ EstimateRadiusByDistance=function(DistanceMatrix){
   # Numerical scalar defining the radius
   # 
 
-  if (!requireNamespace('ABCanalysis')) {
+  if (!requireNamespace('ABCanalysis',quietly = TRUE)) {
     message(
-      'Subordinate clustering package is missing. No computations are performed.
-            Please install the package which is defined in "Suggests".'
+      'Subordinate package (ABCanalysis) is missing. No computations are performed.
+            Please install the package (ABCanalysis) which is defined in "Suggests".'
     )
     return(
       list(
         Radius = 0,
-        Message = "Subordinate clustering package is missing.
+        Message = "Subordinate package (ABCanalysis) is missing.
                 Please install the package which is defined in 'Suggests'."
       )
     )
